# Change Log
All notable changes to this project are documented in this file. This project
adheres to [Semantic Versioning](https://semver.org/).

## 0.0.6 (05-29-2025)
* Updated EDP construction and F1 layer model to be consistent with PyIRI
  v0.0.3 update.
* Added a unit test for IRTAM_EDP_builder_continuous

## 0.0.5 (10-24-2024)
* Updated README to include instructions and fix DOI, Coverage badges
* Fixed documentation links and updated the installation guide

## 0.0.4 (06-07-2024)
* Added a function to retrieve the IRTAM coefficients
* Added a module for IRTAM coefficient functions
* Added unit tests for the IRTAM coefficient functions
* Updated library functions to specify use of subdirectories and removed unused
  args
* Added a package-level directory to store IRTAM coefficients, if desired
* Removed a broken link from the documentation

## 0.0.3 (03-20-2024)
* Fixed import bug, changing the name of the primary sub-module
* Added an error catch for bad IRTAM directory input and unit tests for this
* Added badges to the README

## 0.0.2 (03-18-2024)
* Added community documents
* Added .zenodo.json file
* Added readthedocs build support and badges
* Fixed PEP8 style by removing extra white space, unused imports, and reducing
  duplicate code

## 0.0.1 (11-16-2023)
* Alpha release
